<?php

namespace Asadi\Assignment\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Asadi\Assignment\Interfaces\AssignmentRepositoryInterface;
use Asadi\Assignment\Repositories\Presenter\AssignmentItemTransformer;

/**
 * Pubic API controller class.
 */
class AssignmentPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Asadi\Assignment\Interfaces\AssignmentRepositoryInterface $assignment
     *
     * @return type
     */
    public function __construct(AssignmentRepositoryInterface $assignment)
    {
        $this->repository = $assignment;
        parent::__construct();
    }

    /**
     * Show assignment's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $assignments = $this->repository
            ->setPresenter('\\Asadi\\Assignment\\Repositories\\Presenter\\AssignmentListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $assignments['code'] = 2000;
        return response()->json($assignments)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show assignment.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $assignment = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($assignment)) {
            $assignment         = $this->itemPresenter($module, new AssignmentItemTransformer);
            $assignment['code'] = 2001;
            return response()->json($assignment)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
