<?php

namespace Asadi\Assignment\Http\Controllers\Api;

use App\Http\Controllers\Api\UserController as BaseController;
use Asadi\Assignment\Http\Requests\AssignmentRequest;
use Asadi\Assignment\Interfaces\AssignmentRepositoryInterface;
use Asadi\Assignment\Models\Assignment;

/**
 * User API controller class.
 */
class AssignmentUserController extends BaseController
{
    /**
     * Initialize assignment controller.
     *
     * @param type AssignmentRepositoryInterface $assignment
     *
     * @return type
     */
    public function __construct(AssignmentRepositoryInterface $assignment)
    {
        $this->repository = $assignment;
        $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->pushCriteria(new \Asadi\Assignment\Repositories\Criteria\AssignmentUserCriteria());
        parent::__construct();
    }

    /**
     * Display a list of assignment.
     *
     * @return json
     */
    public function index(AssignmentRequest $request)
    {
        $assignments  = $this->repository
            ->setPresenter('\\Asadi\\Assignment\\Repositories\\Presenter\\AssignmentListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $assignments['code'] = 2000;
        return response()->json($assignments) 
            ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display assignment.
     *
     * @param Request $request
     * @param Model   Assignment
     *
     * @return Json
     */
    public function show(AssignmentRequest $request, Assignment $assignment)
    {

        if ($assignment->exists) {
            $assignment         = $assignment->presenter();
            $assignment['code'] = 2001;
            return response()->json($assignment)
                ->setStatusCode(200, 'SHOW_SUCCESS');;
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }

    /**
     * Show the form for creating a new assignment.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(AssignmentRequest $request, Assignment $assignment)
    {
        $assignment         = $assignment->presenter();
        $assignment['code'] = 2002;
        return response()->json($assignment)
            ->setStatusCode(200, 'CREATE_SUCCESS');
    }

    /**
     * Create new assignment.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(AssignmentRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $assignment          = $this->repository->create($attributes);
            $assignment          = $assignment->presenter();
            $assignment['code']  = 2004;

            return response()->json($assignment)
                ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message' => $e->getMessage(),
                'code'    => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
        }

    }

    /**
     * Show assignment for editing.
     *
     * @param Request $request
     * @param Model   $assignment
     *
     * @return json
     */
    public function edit(AssignmentRequest $request, Assignment $assignment)
    {
        if ($assignment->exists) {
            $assignment         = $assignment->presenter();
            $assignment['code'] = 2003;
            return response()-> json($assignment)
                ->setStatusCode(200, 'EDIT_SUCCESS');;
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }
    }

    /**
     * Update the assignment.
     *
     * @param Request $request
     * @param Model   $assignment
     *
     * @return json
     */
    public function update(AssignmentRequest $request, Assignment $assignment)
    {
        try {

            $attributes = $request->all();

            $assignment->update($attributes);
            $assignment         = $assignment->presenter();
            $assignment['code'] = 2005;

            return response()->json($assignment)
                ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the assignment.
     *
     * @param Request $request
     * @param Model   $assignment
     *
     * @return json
     */
    public function destroy(AssignmentRequest $request, Assignment $assignment)
    {

        try {

            $t = $assignment->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('assignment::assignment.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
