<?php

namespace Asadi\Assignment\Http\Controllers;
use Litepie\Assignment\Http\Requests\AssignmentRequest;
use Litepie\Assignment\Models\Assignment;

trait AssignmentWorkflow {
	
    /**
     * Workflow controller function for assignment.
     *
     * @param Model   $assignment
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(AssignmentRequest $request, Assignment $assignment, $step)
    {

        try {

            $assignment->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('assignment::assignment.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/assignment/assignment/' . $assignment->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/assignment/assignment/' . $assignment->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for assignment.
     *
     * @param Model   $assignment
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Assignment $assignment, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $assignment->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('assignment::assignment.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('assignment::admin.assignment.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('assignment::admin.assignment.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('assignment::admin.assignment.message', $data)->render();

        }

    }
}