<?php

namespace Asadi\Assignment\Policies;

use App\User;
use Asadi\Assignment\Models\Assignment;

class AssignmentPolicy
{

    /**
     * Determine if the given user can view the assignment.
     *
     * @param User $user
     * @param Assignment $assignment
     *
     * @return bool
     */
    public function view(User $user, Assignment $assignment)
    {
        if ($user->canDo('assignment.assignment.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $assignment->user_id;
    }

    /**
     * Determine if the given user can create a assignment.
     *
     * @param User $user
     * @param Assignment $assignment
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('assignment.assignment.create');
    }

    /**
     * Determine if the given user can update the given assignment.
     *
     * @param User $user
     * @param Assignment $assignment
     *
     * @return bool
     */
    public function update(User $user, Assignment $assignment)
    {
        if ($user->canDo('assignment.assignment.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $assignment->user_id;
    }

    /**
     * Determine if the given user can delete the given assignment.
     *
     * @param User $user
     * @param Assignment $assignment
     *
     * @return bool
     */
    public function destroy(User $user, Assignment $assignment)
    {
        if ($user->canDo('assignment.assignment.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $assignment->user_id;
    }

    /**
     * Determine if the given user can verify the given assignment.
     *
     * @param User $user
     * @param Assignment $assignment
     *
     * @return bool
     */
    public function verify(User $user, Assignment $assignment)
    {
        if ($user->canDo('assignment.assignment.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('assignment.assignment.verify') 
        && $user->is('manager')
        && $assignment->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given assignment.
     *
     * @param User $user
     * @param Assignment $assignment
     *
     * @return bool
     */
    public function approve(User $user, Assignment $assignment)
    {
        if ($user->canDo('assignment.assignment.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
